@@ -27,7 +27,8 @@ from squeak.core import CheckSqueak
 from squeak.core import CSqueak
 from squeak.core import MakeSqueakFromStr
 from squeak.core.elliptic import payment_point_bytes_from_scalar_bytes
-from squeak.core.signing import SqueakPrivateKey
+from squeak.core.keys import SqueakPrivateKey
+from squeak.core.keys import SqueakPublicKey
 
 
 DATA_KEY_LENGTH = 32
@@ -58,6 +59,7 @@ def make_squeak_with_block(
         block_height: int,
         block_hash: bytes,
         replyto_hash: Optional[bytes] = None,
+        recipient_public_key: Optional[SqueakPublicKey] = None,
 ) -> Tuple[CSqueak, bytes]:
     """Create a new squeak.
 
@@ -65,8 +67,9 @@ def make_squeak_with_block(
         private_key: The private key to sign the squeak.
         content_str: The content of the squeak as a string.
         block_height: The height of the latest block in the bitcoin blockchain.
-        block_hahs: The hash of the latest block in the bitcoin blockchain.
+        block_hash: The hash of the latest block in the bitcoin blockchain.
         replyto_hash: The hash of the squeak to which this one is replying.
+        recipient_public_key: The public key of the recipient of a private squeak.
 
     Returns:
         Tuple[CSqueak, bytes]: the squeak that was created together
@@ -79,7 +82,8 @@ def make_squeak_with_block(
         block_height,
         block_hash,
         timestamp,
-        replyto_hash,
+        reply_to=replyto_hash,
+        recipient=recipient_public_key,
     )
 
 
@@ -99,7 +103,12 @@ def check_squeak(squeak: CSqueak) -> None:
 
 
 # TODO: return bytes (encoded utf-8 content)
-def get_decrypted_content(squeak: CSqueak, secret_key: bytes) -> str:
+def get_decrypted_content(
+        squeak: CSqueak,
+        secret_key: bytes,
+        authorPrivKey: Optional[SqueakPrivateKey] = None,
+        recipientPrivKey: Optional[SqueakPrivateKey] = None,
+) -> str:
     """Checks if the secret key is valid for the given squeak and returns
     the decrypted content.
 
@@ -113,7 +122,11 @@ def get_decrypted_content(squeak: CSqueak, secret_key: bytes) -> str:
     Raises:
         Exception: If the secret key is not valid.
     """
-    return squeak.GetDecryptedContentStr(secret_key)
+    return squeak.GetDecryptedContentStr(
+        secret_key,
+        authorPrivKey=authorPrivKey,
+        recipientPrivKey=recipientPrivKey,
+    )
 
 
 def get_payment_point_of_secret_key(secret_key: bytes) -> bytes:
